## SCENARIO 1: Zero input groups, 1 of other entities where possible; active scenario; valid

### INPUTS

#### GROUP 1: Unit Test

# | Title | Delimiter
--- | --- | ---
1 | Inner title | ;

####

#### GROUP 2: Input Fields: Empty

#### GROUP 3: Output Fields

# | Group | Field
--- | --- | ---
1 | Output Group 1 | Output Field 1

####

#### GROUP 4: Scenario

# | Scenario | Active Y/N
--- | --- | ---
1 | Inner scenario 1 | Y

####

#### GROUP 5: Input Values: Empty

#### GROUP 6: Expected Values

# | Scenario | Group | Row CSV
--- | --- | --- | ---
1 | Inner scenario 1 | Output Group 1 | Expected value 1

####

#### GROUP 7: Actual Values

# | Scenario | Group | Row CSV
--- | --- | --- | ---
1 | Inner scenario 1 | Output Group 1 | Actual value 1

####

### OUTPUTS

#### GROUP 1: Unit Test

# | Title | Delimiter
--- | --- | ---
1 | Inner title | ;

#### 0 failed of 1: SUCCESS

#### GROUP 2: Input Fields: Empty as expected: SUCCESS

#### GROUP 3: Output Fields

# | Group | Field
--- | --- | ---
1 | Output Group 1 | Output Field 1

#### 0 failed of 1: SUCCESS

#### GROUP 4: Input Values: Empty as expected: SUCCESS

#### GROUP 5: Expected Values

# | Scenario | Group | Row CSV
--- | --- | --- | ---
1 | Inner scenario 1 | Output Group 1 | Expected value 1

#### 0 failed of 1: SUCCESS

#### GROUP 6: Actual Values

# | Scenario | Group | Row CSV
--- | --- | --- | ---
1 | Inner scenario 1 | Output Group 1 | Actual value 1

#### 0 failed of 1: SUCCESS

## 0 failed of 6: SUCCESS